=============
known
=============

**known** is a collection of reusable python code. Use pip to install **known**

.. code-block:: console

   $ pip install known

The package is frequently updated by adding new functionality, make sure to have the latest version. To check version use

.. code-block:: console

   >>> import known
   >>> known.__version__

Visit PyPI package `homepage <https://pypi.org/project/known>`__
